# FolderUserProject

 This is a flattened nested represetation of FosUser and Invitation models in this serializer. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [readonly] 
**user_id** | **int** |  | [optional] [readonly] 
**invitation_id** | **int** |  | [optional] [readonly] 
**email** | **str** |  | [optional] [readonly] 
**firstname** | **str** |  | [optional] [readonly] 
**lastname** | **str** |  | [optional] [readonly] 
**profile_picture** | **str** |  | [optional] [readonly] 
**role** | **int** |  | [optional] [readonly] 
**permission** | **int** |  | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


